pub struct ComponentNode {
pub name: String,
pub is_inline: bool,
pub attributes: Vec<AttributeNode>,
pub children: Vec<Node>,
pub raw_content: String,
pub position: Position,
}Expand description
An RDX component node.
Fields
name: Stringis_inline: boolattributes: Vec<AttributeNode>children: Vec<Node>raw_content: StringRaw source text of the component body (between open/close tags). Preserved verbatim for components that need whitespace-sensitive content (e.g. CodeBlock). Empty for self-closing components.
position: PositionTrait Implementations
Sourceimpl Archive for ComponentNode
impl Archive for ComponentNode
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ComponentNode>
const COPY_OPTIMIZATION: CopyOptimization<ComponentNode>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedComponentNode
type Archived = ArchivedComponentNode
The archived representation of this type. Read more
Sourcetype Resolver = ComponentNodeResolver
type Resolver = ComponentNodeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ComponentNode
impl Clone for ComponentNode
Sourcefn clone(&self) -> ComponentNode
fn clone(&self) -> ComponentNode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComponentNode
impl Debug for ComponentNode
Sourceimpl<'de> Deserialize<'de> for ComponentNode
impl<'de> Deserialize<'de> for ComponentNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ComponentNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ComponentNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D> Deserialize<ComponentNode, __D> for <ComponentNode as Archive>::Archived
impl<__D> Deserialize<ComponentNode, __D> for <ComponentNode as Archive>::Archived
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ComponentNode, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ComponentNode, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for ComponentNode
impl PartialEq for ComponentNode
Sourceimpl<__S> Serialize<__S> for ComponentNode
impl<__S> Serialize<__S> for ComponentNode
Sourceimpl Serialize for ComponentNode
impl Serialize for ComponentNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ComponentNode