pub struct ErrorNode {
pub message: String,
pub raw_content: String,
pub position: Position,
}Expand description
An explicit error node for host-level error boundaries.
Fields
message: Stringraw_content: Stringposition: PositionTrait Implementations
Sourceimpl Archive for ErrorNode
impl Archive for ErrorNode
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ErrorNode>
const COPY_OPTIMIZATION: CopyOptimization<ErrorNode>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedErrorNode
type Archived = ArchivedErrorNode
The archived representation of this type. Read more
Sourcetype Resolver = ErrorNodeResolver
type Resolver = ErrorNodeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl<'de> Deserialize<'de> for ErrorNode
impl<'de> Deserialize<'de> for ErrorNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ErrorNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ErrorNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for ErrorNode
impl Serialize for ErrorNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for ErrorNode
impl StructuralPartialEq for ErrorNode