pub struct FootnoteNode {
pub label: String,
pub children: Vec<Node>,
pub position: Position,
}Expand description
A footnote node (definition or reference).
Fields
label: Stringchildren: Vec<Node>position: PositionTrait Implementations
Sourceimpl Archive for FootnoteNode
impl Archive for FootnoteNode
Sourceconst COPY_OPTIMIZATION: CopyOptimization<FootnoteNode>
const COPY_OPTIMIZATION: CopyOptimization<FootnoteNode>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedFootnoteNode
type Archived = ArchivedFootnoteNode
The archived representation of this type. Read more
Sourcetype Resolver = FootnoteNodeResolver
type Resolver = FootnoteNodeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for FootnoteNode
impl Clone for FootnoteNode
Sourcefn clone(&self) -> FootnoteNode
fn clone(&self) -> FootnoteNode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FootnoteNode
impl Debug for FootnoteNode
Sourceimpl<'de> Deserialize<'de> for FootnoteNode
impl<'de> Deserialize<'de> for FootnoteNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<FootnoteNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<FootnoteNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D> Deserialize<FootnoteNode, __D> for <FootnoteNode as Archive>::Archived
impl<__D> Deserialize<FootnoteNode, __D> for <FootnoteNode as Archive>::Archived
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<FootnoteNode, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<FootnoteNode, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for FootnoteNode
impl PartialEq for FootnoteNode
Sourceimpl<__S> Serialize<__S> for FootnoteNode
impl<__S> Serialize<__S> for FootnoteNode
Sourceimpl Serialize for FootnoteNode
impl Serialize for FootnoteNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for FootnoteNode