pub struct Position {
pub start: Point,
pub end: Point,
}Expand description
Positional data mapping an AST node back to its source .rdx file.
Line and column numbers are 1-indexed. Offsets are 0-indexed byte offsets.
Fields
start: Pointend: PointTrait Implementations
Sourceimpl Archive for Position
impl Archive for Position
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Position>
const COPY_OPTIMIZATION: CopyOptimization<Position>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedPosition
type Archived = ArchivedPosition
The archived representation of this type. Read more
Sourcetype Resolver = PositionResolver
type Resolver = PositionResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl<'de> Deserialize<'de> for Position
impl<'de> Deserialize<'de> for Position
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Position, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Position, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for Position
impl Serialize for Position
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for Position
impl StructuralPartialEq for Position