pub struct StandardBlockNode {
pub depth: Option<u8>,
pub ordered: Option<bool>,
pub checked: Option<bool>,
pub id: Option<String>,
pub children: Vec<Node>,
pub position: Position,
}Expand description
A standard CommonMark block node.
Fields
depth: Option<u8>ordered: Option<bool>checked: Option<bool>For list items: whether a task list checkbox is checked.
id: Option<String>For headings: an explicit ID attribute (# Title {#my-id}).
children: Vec<Node>position: PositionTrait Implementations
Sourceimpl Archive for StandardBlockNode
impl Archive for StandardBlockNode
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StandardBlockNode>
const COPY_OPTIMIZATION: CopyOptimization<StandardBlockNode>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedStandardBlockNode
type Archived = ArchivedStandardBlockNode
The archived representation of this type. Read more
Sourcetype Resolver = StandardBlockNodeResolver
type Resolver = StandardBlockNodeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for StandardBlockNode
impl Clone for StandardBlockNode
Sourcefn clone(&self) -> StandardBlockNode
fn clone(&self) -> StandardBlockNode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StandardBlockNode
impl Debug for StandardBlockNode
Sourceimpl<'de> Deserialize<'de> for StandardBlockNode
impl<'de> Deserialize<'de> for StandardBlockNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<StandardBlockNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<StandardBlockNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D> Deserialize<StandardBlockNode, __D> for <StandardBlockNode as Archive>::Archivedwhere
__D: Fallible + ?Sized,
<__D as Fallible>::Error: Source,
Option<u8>: Archive,
<Option<u8> as Archive>::Archived: Deserialize<Option<u8>, __D>,
Option<bool>: Archive,
<Option<bool> as Archive>::Archived: Deserialize<Option<bool>, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Position: Archive,
<Position as Archive>::Archived: Deserialize<Position, __D>,
impl<__D> Deserialize<StandardBlockNode, __D> for <StandardBlockNode as Archive>::Archivedwhere
__D: Fallible + ?Sized,
<__D as Fallible>::Error: Source,
Option<u8>: Archive,
<Option<u8> as Archive>::Archived: Deserialize<Option<u8>, __D>,
Option<bool>: Archive,
<Option<bool> as Archive>::Archived: Deserialize<Option<bool>, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Position: Archive,
<Position as Archive>::Archived: Deserialize<Position, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<StandardBlockNode, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<StandardBlockNode, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for StandardBlockNode
impl PartialEq for StandardBlockNode
Sourceimpl<__S> Serialize<__S> for StandardBlockNode
impl<__S> Serialize<__S> for StandardBlockNode
Sourceimpl Serialize for StandardBlockNode
impl Serialize for StandardBlockNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for StandardBlockNode