pub struct TextNode {
pub value: String,
pub position: Position,
}Expand description
A literal text node.
Fields
value: Stringposition: PositionTrait Implementations
Sourceimpl Archive for TextNode
impl Archive for TextNode
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TextNode>
const COPY_OPTIMIZATION: CopyOptimization<TextNode>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedTextNode
type Archived = ArchivedTextNode
The archived representation of this type. Read more
Sourcetype Resolver = TextNodeResolver
type Resolver = TextNodeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl<'de> Deserialize<'de> for TextNode
impl<'de> Deserialize<'de> for TextNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TextNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TextNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for TextNode
impl Serialize for TextNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for TextNode
impl StructuralPartialEq for TextNode