pub struct VariableNode {
pub path: String,
pub position: Position,
}Expand description
A variable interpolation node.
Fields
path: Stringposition: PositionTrait Implementations
Sourceimpl Archive for VariableNode
impl Archive for VariableNode
Sourceconst COPY_OPTIMIZATION: CopyOptimization<VariableNode>
const COPY_OPTIMIZATION: CopyOptimization<VariableNode>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedVariableNode
type Archived = ArchivedVariableNode
The archived representation of this type. Read more
Sourcetype Resolver = VariableNodeResolver
type Resolver = VariableNodeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for VariableNode
impl Clone for VariableNode
Sourcefn clone(&self) -> VariableNode
fn clone(&self) -> VariableNode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VariableNode
impl Debug for VariableNode
Sourceimpl<'de> Deserialize<'de> for VariableNode
impl<'de> Deserialize<'de> for VariableNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<VariableNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<VariableNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D> Deserialize<VariableNode, __D> for <VariableNode as Archive>::Archived
impl<__D> Deserialize<VariableNode, __D> for <VariableNode as Archive>::Archived
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<VariableNode, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<VariableNode, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for VariableNode
impl PartialEq for VariableNode
Sourceimpl<__S> Serialize<__S> for VariableNode
impl<__S> Serialize<__S> for VariableNode
Sourceimpl Serialize for VariableNode
impl Serialize for VariableNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for VariableNode
impl StructuralPartialEq for VariableNode