pub struct AbbreviationExpand;Expand description
Reads abbreviations from the document frontmatter and wraps the first
occurrence of each abbreviation in the document text with an <Abbr>
inline component that carries a title attribute containing the expansion.
Frontmatter format
---
abbreviations:
HTML: HyperText Markup Language
CSS: Cascading Style Sheets
---The above will wrap the first occurrence of the literal string "HTML" with
<Abbr title="HyperText Markup Language">HTML</Abbr> and similarly for
"CSS".
Subsequent occurrences of the same abbreviation are left as plain text.
Notes
- Only
Node::Textnodes inside the document body are searched. - If the frontmatter is absent, or has no
abbreviationsmap, the transform is a no-op. - Abbreviation matching is case-sensitive and is done on exact sub-string boundaries (the abbreviation must appear as-is in the text).